==> ejc-zdsmaterialb-api-3.0.0-20240802.102206-4-sources.jar: com/ejianc/business/zdsmaterial/out/vo/OutStoreVO.java <==
package com.ejianc.business.zdsmaterial.out.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 领料出库
 * 
 * @author generator
 * 
 */
@ApiModel("领料出库")
public class OutStoreVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("单据状态")
    private Integer billState;
    @ApiModelProperty("出库单号")
    private String billCode;
    @ApiModelProperty("领料日期")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date outDate;
    @ApiModelProperty("出库物资名称集合")
    private String materialNames;
    @ApiModelProperty("出库数量")
    private BigDecimal outNum;
    @ApiModelProperty("出库金额")
    private BigDecimal outMny;
    @ApiModelProperty("出库金额含税")
    private BigDecimal outTaxMny;
    @ApiModelProperty("用处")
    private String useFor;
    @ApiModelProperty("备注")
    private String memo;
    @ApiModelProperty("经办人id")
    private Long employeeId;
    @ApiModelProperty("经办人名称")
    private String employeeName;
    @ApiModelProperty("项目名称")
    private String projectName;
    @ApiModelProperty("项目id")
    private Long projectId;
    @ApiModelProperty("所属项目编码")
    private String projectCode;
    @ApiModelProperty("组织id")
    private Long orgId;
    @ApiModelProperty("组织名称")
    private String orgName;
    private String orgCode; // 组织编码
    @ApiModelProperty("合同id")
    private Long subContractId;
    @ApiModelProperty("合同名称")
    private String subContractName;
    @ApiModelProperty("分包单位")
    private String subSupplierName;
    @ApiModelProperty("供应商id")
    private Long subSupplierId;
    @ApiModelProperty("分包领料人主键")
    private Long subEmployeeId; // 分包领料人主键
    @ApiModelProperty("分包负责人")
    private String subEmployeeName;
    @ApiModelProperty("分包负责人电话")
    private String subEmployeeMobile;
    @ApiModelProperty("项目部上级组织Id")
    private Long parentOrgId;
    @ApiModelProperty("项目部上级组织名称")
    private String parentOrgName;
    @ApiModelProperty("项目部上级组织编码")
    private String parentOrgCode;
    @ApiModelProperty("合同code")
    private String subContractCode;
    @ApiModelProperty("经办部门")
    private Long departmentId;
    @ApiModelProperty("经办部门名称")
    private String departmentName;
    @ApiModelProperty("签字状态")
    private Integer signStatus; // 签字状态，0-未签字,1-已签字
    @ApiModelProperty("领料出库明细")
    @SubEntity
    private List<OutStoreSubVO> outStoreSubList = new ArrayList<>();
    private Integer claimType; // 领料方式，1-分包领料,2-内部领料
    private Integer sourceType; // 来源方式，1-自制,2-供方发起
    private String confirmState; // 确认状态(0-待确认,1-已确认,2-已驳回）
    private String sourceId;// 来源业务单据Id
    private String systemId; // 来源系统主键
    private Long createUserId;// 制单人Id

    /**
     * 供方经办人名称
     */
    private String supOperatorName;

    /**
     * 供方经办人手机号
     */
    private String supOperatorPhone;
    /**
     * 供方经办人账号
     */
    private String supOperatorUserCode;

    /**
     * 供方经办人签字时间
     */
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM-dd HH:mm:ss",
            timezone = "GMT+8"
    )
    private Date supOperateTime;

    /**
     * 供方经办人签字文件id
     */
    private Long supOperateFileId;
    /**
     * 单据推送标识：unSucPush-未成功推送供方，sucPushed-已成功推送供方
     */
    private String billPushFlag;

    private Boolean confirmEnable; // 是否可确认


    public Integer getClaimType() {
        return claimType;
    }

    public void setClaimType(Integer claimType) {
        this.claimType = claimType;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getBillPushFlag() {
        return billPushFlag;
    }

    public void setBillPushFlag(String billPushFlag) {
        this.billPushFlag = billPushFlag;
    }

    public Integer getSignStatus() {
        return signStatus;
    }

    public void setSignStatus(Integer signStatus) {
        this.signStatus = signStatus;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public String getConfirmState() {
        return confirmState;
    }

    public void setConfirmState(String confirmState) {
        this.confirmState = confirmState;
    }

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public String getSystemId() {
        return systemId;
    }

    public void setSystemId(String systemId) {
        this.systemId = systemId;
    }

    public String getSupOperatorName() {
        return supOperatorName;
    }

    public void setSupOperatorName(String supOperatorName) {
        this.supOperatorName = supOperatorName;
    }

    public String getSupOperatorPhone() {
        return supOperatorPhone;
    }

    public void setSupOperatorPhone(String supOperatorPhone) {
        this.supOperatorPhone = supOperatorPhone;
    }

    public String getSupOperatorUserCode() {
        return supOperatorUserCode;
    }

    public void setSupOperatorUserCode(String supOperatorUserCode) {
        this.supOperatorUserCode = supOperatorUserCode;
    }

    public Date getSupOperateTime() {
        return supOperateTime;
    }

    public void setSupOperateTime(Date supOperateTime) {
        this.supOperateTime = supOperateTime;
    }

    public Long getSupOperateFileId() {
        return supOperateFileId;
    }

    public void setSupOperateFileId(Long supOperateFileId) {
        this.supOperateFileId = supOperateFileId;
    }

    public Boolean getConfirmEnable() {
        return confirmEnable;
    }

    public void setConfirmEnable(Boolean confirmEnable) {
        this.confirmEnable = confirmEnable;
    }

    /**
     * 单据状态
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 出库单号
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 出库单号
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 领料日期
     */
    public Date getOutDate() {
        return outDate;
    }

    /**
     * 领料日期
     */
    public void setOutDate(Date outDate) {
        this.outDate = outDate;
    }
    /**
     * 出库物资名称集合
     */
    public String getMaterialNames() {
        return materialNames;
    }

    /**
     * 出库物资名称集合
     */
    public void setMaterialNames(String materialNames) {
        this.materialNames = materialNames;
    }
    /**
     * 出库数量
     */
    public BigDecimal getOutNum() {
        return outNum;
    }

    /**
     * 出库数量
     */
    public void setOutNum(BigDecimal outNum) {
        this.outNum = outNum;
    }
    /**
     * 出库金额
     */
    public BigDecimal getOutMny() {
        return outMny;
    }

    /**
     * 出库金额
     */
    public void setOutMny(BigDecimal outMny) {
        this.outMny = outMny;
    }
    /**
     * 出库金额含税
     */
    public BigDecimal getOutTaxMny() {
        return outTaxMny;
    }

    /**
     * 出库金额含税
     */
    public void setOutTaxMny(BigDecimal outTaxMny) {
        this.outTaxMny = outTaxMny;
    }
    /**
     * 用处
     */
    public String getUseFor() {
        return useFor;
    }

    /**
     * 用处
     */
    public void setUseFor(String useFor) {
        this.useFor = useFor;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 经办人id
     */
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 经办人名称
     */
    public String getEmployeeName() {
        return employeeName;
    }

    /**
     * 经办人名称
     */
    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="project-set")
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 所属项目编码
     */
    public String getProjectCode() {
        return projectCode;
    }

    /**
     * 所属项目编码
     */
    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 组织id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 合同id
     */
    @ReferSerialTransfer(referCode="sub-contract-ref")
    public Long getSubContractId() {
        return subContractId;
    }

    /**
     * 合同id
     */
    @ReferDeserialTransfer
    public void setSubContractId(Long subContractId) {
        this.subContractId = subContractId;
    }
    /**
     * 合同名称
     */
    public String getSubContractName() {
        return subContractName;
    }

    /**
     * 合同名称
     */
    public void setSubContractName(String subContractName) {
        this.subContractName = subContractName;
    }
    /**
     * 分包单位
     */
    public String getSubSupplierName() {
        return subSupplierName;
    }

    /**
     * 分包单位
     */
    public void setSubSupplierName(String subSupplierName) {
        this.subSupplierName = subSupplierName;
    }
    /**
     * 供应商id
     */
    public Long getSubSupplierId() {
        return subSupplierId;
    }

    /**
     * 供应商id
     */
    public void setSubSupplierId(Long subSupplierId) {
        this.subSupplierId = subSupplierId;
    }

//    @ReferSerialTransfer(referCode="idm-employee")
    public Long getSubEmployeeId() {
        return subEmployeeId;
    }

    @ReferDeserialTransfer
    public void setSubEmployeeId(Long subEmployeeId) {
        this.subEmployeeId = subEmployeeId;
    }

    /**
     * 分包负责人
     */
    public String getSubEmployeeName() {
        return subEmployeeName;
    }

    /**
     * 分包负责人
     */
    public void setSubEmployeeName(String subEmployeeName) {
        this.subEmployeeName = subEmployeeName;
    }
    /**
     * 分包负责人电话
     */
    public String getSubEmployeeMobile() {
        return subEmployeeMobile;
    }

    /**
     * 分包负责人电话
     */
    public void setSubEmployeeMobile(String subEmployeeMobile) {
        this.subEmployeeMobile = subEmployeeMobile;
    }
    /**
     * 项目部上级组织Id
     */
    public Long getParentOrgId() {
        return parentOrgId;
    }

    /**
     * 项目部上级组织Id
     */
    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    /**
     * 项目部上级组织名称
     */
    public String getParentOrgName() {
        return parentOrgName;
    }

    /**
     * 项目部上级组织名称
     */
    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getSubContractCode() {
        return subContractCode;
    }

    public void setSubContractCode(String subContractCode) {
        this.subContractCode = subContractCode;
    }
    /**
     * 经办部门
     */
    public Long getDepartmentId() {
        return departmentId;
    }

    /**
     * 经办部门
     */
    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    /**
     * 经办部门名称
     */
    public String getDepartmentName() {
        return departmentName;
    }

    /**
     * 经办部门名称
     */
    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }
    
     /**
      * 领料出库明细
      */
      public List<OutStoreSubVO> getOutStoreSubList() {
         return outStoreSubList;
      }
     /**
      * 领料出库明细
      */
     public void setOutStoreSubList(List<OutStoreSubVO> outStoreSubList) {
         this.outStoreSubList = outStoreSubList;
     }
}

==> ejc-zdsmaterialb-api-3.0.0-20251206.064345-102-sources.jar: com/ejianc/business/zdsmaterial/out/vo/OutStoreVO.java <==
package com.ejianc.business.zdsmaterial.out.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 领料出库
 * 
 * @author generator
 * 
 */
@ApiModel("领料出库")
public class OutStoreVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("单据状态")
    private Integer billState;
    @ApiModelProperty("出库单号")
    private String billCode;
    @ApiModelProperty("领料日期")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date outDate;
    @ApiModelProperty("出库物资名称集合")
    private String materialNames;
    @ApiModelProperty("出库数量")
    private BigDecimal outNum;
    @ApiModelProperty("出库金额")
    private BigDecimal outMny;
    @ApiModelProperty("出库金额含税")
    private BigDecimal outTaxMny;
    @ApiModelProperty("用处")
    private String useFor;
    @ApiModelProperty("备注")
    private String memo;
    @ApiModelProperty("经办人id")
    private Long employeeId;
    @ApiModelProperty("经办人名称")
    private String employeeName;
    @ApiModelProperty("项目名称")
    private String projectName;
    @ApiModelProperty("项目id")
    private Long projectId;
    @ApiModelProperty("所属项目编码")
    private String projectCode;
    @ApiModelProperty("组织id")
    private Long orgId;
    @ApiModelProperty("组织名称")
    private String orgName;
    private String orgCode; // 组织编码
    @ApiModelProperty("合同id")
    private Long subContractId;
    @ApiModelProperty("合同名称")
    private String subContractName;
    @ApiModelProperty("分包单位")
    private String subSupplierName;
    @ApiModelProperty("供应商id")
    private Long subSupplierId;
    @ApiModelProperty("分包领料人主键")
    private Long subEmployeeId; // 分包领料人主键
    @ApiModelProperty("分包负责人")
    private String subEmployeeName;
    @ApiModelProperty("分包负责人电话")
    private String subEmployeeMobile;
    @ApiModelProperty("项目部上级组织Id")
    private Long parentOrgId;
    @ApiModelProperty("项目部上级组织名称")
    private String parentOrgName;
    @ApiModelProperty("项目部上级组织编码")
    private String parentOrgCode;
    @ApiModelProperty("合同code")
    private String subContractCode;
    @ApiModelProperty("经办部门")
    private Long departmentId;
    @ApiModelProperty("经办部门名称")
    private String departmentName;
    @ApiModelProperty("签字状态")
    private Integer signStatus; // 签字状态，0-未签字,1-已签字
    @ApiModelProperty("领料出库明细")
    @SubEntity
    private List<OutStoreSubVO> outStoreSubList = new ArrayList<>();
    private Integer claimType; // 领料方式，1-分包领料,2-内部领料
    private Integer sourceType; // 来源方式，1-自制,2-供方发起
    private String confirmState; // 确认状态(0-待确认,1-已确认,2-已驳回）
    private String sourceId;// 来源业务单据Id
    private String systemId; // 来源系统主键
    private Long createUserId;// 制单人Id

    /**
     * 供方经办人名称
     */
    private String supOperatorName;

    /**
     * 供方经办人手机号
     */
    private String supOperatorPhone;
    /**
     * 供方经办人账号
     */
    private String supOperatorUserCode;

    /**
     * 供方经办人签字时间
     */
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM-dd HH:mm:ss",
            timezone = "GMT+8"
    )
    private Date supOperateTime;

    /**
     * 供方经办人签字文件id
     */
    private Long supOperateFileId;
    /**
     * 单据推送标识：unSucPush-未成功推送供方，sucPushed-已成功推送供方
     */
    private String billPushFlag;

    private Boolean confirmEnable; // 是否可确认

    private Date effectDate; // 生效日期
    private Long approveUserId; // 审批人主键
    private String approveUserName; // 审批人名称


    public Integer getClaimType() {
        return claimType;
    }

    public void setClaimType(Integer claimType) {
        this.claimType = claimType;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getBillPushFlag() {
        return billPushFlag;
    }

    public void setBillPushFlag(String billPushFlag) {
        this.billPushFlag = billPushFlag;
    }

    public Integer getSignStatus() {
        return signStatus;
    }

    public void setSignStatus(Integer signStatus) {
        this.signStatus = signStatus;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public String getConfirmState() {
        return confirmState;
    }

    public void setConfirmState(String confirmState) {
        this.confirmState = confirmState;
    }

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public String getSystemId() {
        return systemId;
    }

    public void setSystemId(String systemId) {
        this.systemId = systemId;
    }

    public String getSupOperatorName() {
        return supOperatorName;
    }

    public void setSupOperatorName(String supOperatorName) {
        this.supOperatorName = supOperatorName;
    }

    public String getSupOperatorPhone() {
        return supOperatorPhone;
    }

    public void setSupOperatorPhone(String supOperatorPhone) {
        this.supOperatorPhone = supOperatorPhone;
    }

    public String getSupOperatorUserCode() {
        return supOperatorUserCode;
    }

    public void setSupOperatorUserCode(String supOperatorUserCode) {
        this.supOperatorUserCode = supOperatorUserCode;
    }

    public Date getSupOperateTime() {
        return supOperateTime;
    }

    public void setSupOperateTime(Date supOperateTime) {
        this.supOperateTime = supOperateTime;
    }

    public Long getSupOperateFileId() {
        return supOperateFileId;
    }

    public void setSupOperateFileId(Long supOperateFileId) {
        this.supOperateFileId = supOperateFileId;
    }

    public Boolean getConfirmEnable() {
        return confirmEnable;
    }

    public void setConfirmEnable(Boolean confirmEnable) {
        this.confirmEnable = confirmEnable;
    }

    /**
     * 单据状态
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 出库单号
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 出库单号
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 领料日期
     */
    public Date getOutDate() {
        return outDate;
    }

    /**
     * 领料日期
     */
    public void setOutDate(Date outDate) {
        this.outDate = outDate;
    }
    /**
     * 出库物资名称集合
     */
    public String getMaterialNames() {
        return materialNames;
    }

    /**
     * 出库物资名称集合
     */
    public void setMaterialNames(String materialNames) {
        this.materialNames = materialNames;
    }
    /**
     * 出库数量
     */
    public BigDecimal getOutNum() {
        return outNum;
    }

    /**
     * 出库数量
     */
    public void setOutNum(BigDecimal outNum) {
        this.outNum = outNum;
    }
    /**
     * 出库金额
     */
    public BigDecimal getOutMny() {
        return outMny;
    }

    /**
     * 出库金额
     */
    public void setOutMny(BigDecimal outMny) {
        this.outMny = outMny;
    }
    /**
     * 出库金额含税
     */
    public BigDecimal getOutTaxMny() {
        return outTaxMny;
    }

    /**
     * 出库金额含税
     */
    public void setOutTaxMny(BigDecimal outTaxMny) {
        this.outTaxMny = outTaxMny;
    }
    /**
     * 用处
     */
    public String getUseFor() {
        return useFor;
    }

    /**
     * 用处
     */
    public void setUseFor(String useFor) {
        this.useFor = useFor;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 经办人id
     */
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 经办人名称
     */
    public String getEmployeeName() {
        return employeeName;
    }

    /**
     * 经办人名称
     */
    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="project-set")
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 所属项目编码
     */
    public String getProjectCode() {
        return projectCode;
    }

    /**
     * 所属项目编码
     */
    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 组织id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 合同id
     */
    @ReferSerialTransfer(referCode="sub-contract-ref")
    public Long getSubContractId() {
        return subContractId;
    }

    /**
     * 合同id
     */
    @ReferDeserialTransfer
    public void setSubContractId(Long subContractId) {
        this.subContractId = subContractId;
    }
    /**
     * 合同名称
     */
    public String getSubContractName() {
        return subContractName;
    }

    /**
     * 合同名称
     */
    public void setSubContractName(String subContractName) {
        this.subContractName = subContractName;
    }
    /**
     * 分包单位
     */
    public String getSubSupplierName() {
        return subSupplierName;
    }

    /**
     * 分包单位
     */
    public void setSubSupplierName(String subSupplierName) {
        this.subSupplierName = subSupplierName;
    }
    /**
     * 供应商id
     */
    public Long getSubSupplierId() {
        return subSupplierId;
    }

    /**
     * 供应商id
     */
    public void setSubSupplierId(Long subSupplierId) {
        this.subSupplierId = subSupplierId;
    }

//    @ReferSerialTransfer(referCode="idm-employee")
    public Long getSubEmployeeId() {
        return subEmployeeId;
    }

    @ReferDeserialTransfer
    public void setSubEmployeeId(Long subEmployeeId) {
        this.subEmployeeId = subEmployeeId;
    }

    /**
     * 分包负责人
     */
    public String getSubEmployeeName() {
        return subEmployeeName;
    }

    /**
     * 分包负责人
     */
    public void setSubEmployeeName(String subEmployeeName) {
        this.subEmployeeName = subEmployeeName;
    }
    /**
     * 分包负责人电话
     */
    public String getSubEmployeeMobile() {
        return subEmployeeMobile;
    }

    /**
     * 分包负责人电话
     */
    public void setSubEmployeeMobile(String subEmployeeMobile) {
        this.subEmployeeMobile = subEmployeeMobile;
    }
    /**
     * 项目部上级组织Id
     */
    public Long getParentOrgId() {
        return parentOrgId;
    }

    /**
     * 项目部上级组织Id
     */
    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    /**
     * 项目部上级组织名称
     */
    public String getParentOrgName() {
        return parentOrgName;
    }

    /**
     * 项目部上级组织名称
     */
    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getSubContractCode() {
        return subContractCode;
    }

    public void setSubContractCode(String subContractCode) {
        this.subContractCode = subContractCode;
    }
    /**
     * 经办部门
     */
    public Long getDepartmentId() {
        return departmentId;
    }

    /**
     * 经办部门
     */
    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    /**
     * 经办部门名称
     */
    public String getDepartmentName() {
        return departmentName;
    }

    /**
     * 经办部门名称
     */
    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public Date getEffectDate() {
        return effectDate;
    }

    public void setEffectDate(Date effectDate) {
        this.effectDate = effectDate;
    }

    public Long getApproveUserId() {
        return approveUserId;
    }

    public void setApproveUserId(Long approveUserId) {
        this.approveUserId = approveUserId;
    }

    public String getApproveUserName() {
        return approveUserName;
    }

    public void setApproveUserName(String approveUserName) {
        this.approveUserName = approveUserName;
    }
    
     /**
      * 领料出库明细
      */
      public List<OutStoreSubVO> getOutStoreSubList() {
         return outStoreSubList;
      }
     /**
      * 领料出库明细
      */
     public void setOutStoreSubList(List<OutStoreSubVO> outStoreSubList) {
         this.outStoreSubList = outStoreSubList;
     }
}
